@@ -20,8 +20,9 @@ _float_pattern = '\d+(.\d+)?'
 # regex to match signal patterns
 _signal_re = re.compile(
     '(?P<name>.+),\s+'
-    f'[Ss][Ii][Gg]=(?P<wavelength>{_float_pattern}),(?P<width>{_float_pattern})\s+'
-    f'[Rr][Ee][Ff]=(?P<ref_string>(?P<ref>[Oo][Ff][Ff]|(?P<ref_wl>{_float_pattern}),(?P<ref_width>{_float_pattern})))'
+    f'sig=(?P<wavelength>{_float_pattern}),(?P<width>{_float_pattern})\s+'
+    f'ref=(?P<ref_string>(?P<ref>off|(?P<ref_wl>{_float_pattern}),(?P<ref_width>{_float_pattern})))',
+    re.IGNORECASE
 )
 # separate regex to catch simple wavelength,bandwidth specification
 _simple_re = re.compile(
